# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import os
import platform
from . import tools
from . import parser

__version__ = "0.17"

Log = tools.minimal_logger(__name__)


#: Module instance properties, can be mocked for testing
distro = platform.system()


def get_parser_class():
    """
    Returns the parser according to the system platform
    """
    global distro
    if distro == 'Linux':
        Parser = parser.LinuxParser
        if not os.path.exists(Parser.get_command()[0]):
            Parser = parser.UnixIPParser
    elif distro in ['Darwin', 'MacOSX']:
        Parser = parser.MacOSXParser
    elif distro == 'Windows':
        # For some strange reason, Windows will always be win32, see:
        # https://stackoverflow.com/a/2145582/405682
        Parser = parser.WindowsParser
    else:
        Parser = parser.NullParser
        Log.error("Unknown distro type '%s'." % distro)
    Log.debug("Distro detected as '%s'" % distro)
    Log.debug("Using '%s'" % Parser)

    return Parser


#: Module instance properties, can be mocked for testing
Parser = get_parser_class()


def get_parser(ifconfig=None):
    """
    Detect the proper parser class, and return it instantiated.

    Optional Arguments:

        ifconfig
            The ifconfig (stdout) to pass to the parser (used for testing).

    """
    global Parser
    return Parser(ifconfig=ifconfig)


def interfaces(ifconfig=None):
    """
    Return just the parsed interfaces dictionary from the proper parser.

    """
    global Parser
    return Parser(ifconfig=ifconfig).interfaces


def default_interface(ifconfig=None, route_output=None):
    """
    Return just the default interface device dictionary.

    :param ifconfig: For mocking actual command output
    :param route_output: For mocking actual command output
    """
    global Parser
    return Parser(ifconfig=ifconfig)._default_interface(route_output=route_output)



import os
import sys

from setuptools import find_packages, setup

sys.path.append(os.path.join(os.path.dirname(__file__), 'src'))

import ifcfg  # noqa


setup(
    name='ifcfg',
    version=ifcfg.__version__,
    description="Python Ifconfig Wrapper for Unix/Linux/MacOSX",
    long_description=open("README.rst").read(),
    keywords='',
    author='Original author: BJ Dierkes',
    author_email='info@learningequality.org',
    url='https://github.com/ftao/python-ifcfg',
    license='BSD',
    packages=find_packages('src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    test_suite='nose.collector',
    install_requires=[],
    setup_requires=[],
    entry_points="""
    """,
    namespace_packages=[],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
)
